<?xml version="1.0"?>
<app>

<category>
FileManagers
</category>

<name>
PCManFM
</name>

<description>
   <am>a fast and lightweight file manager</am>
   <ar>a fast and lightweight file manager</ar>
   <bg>a fast and lightweight file manager</bg>
   <ca>Un gestor de fitxers ràpid i lleuger</ca>
   <cs>a fast and lightweight file manager</cs>
   <da>en hurtig og letvægts filhåndtering</da>
   <de>Ein schneller und leichter Dateimanager</de>
   <el>ένα γρήγορο και ελαφρύ διαχειριστή αρχείων</el>
   <en>a fast and lightweight file manager</en>
   <es>Gestor de archivos rápido y liviano</es>
   <et>a fast and lightweight file manager</et>
   <eu>a fast and lightweight file manager</eu>
   <fa>a fast and lightweight file manager</fa>
   <fi>a fast and lightweight file manager</fi>
   <fr>Un gestionnaire de fichiers rapide et léger</fr>
   <he_IL>a fast and lightweight file manager</he_IL>
   <hi>a fast and lightweight file manager</hi>
   <hr>a fast and lightweight file manager</hr>
   <hu>a fast and lightweight file manager</hu>
   <id>a fast and lightweight file manager</id>
   <is>a fast and lightweight file manager</is>
   <it>file manager veloce e leggero</it>
   <ja_JP>a fast and lightweight file manager</ja_JP>
   <ja>a fast and lightweight file manager</ja>
   <kk>a fast and lightweight file manager</kk>
   <ko>a fast and lightweight file manager</ko>
   <lt>greita ir supaprastinta failų tvarkytuvė</lt>
   <mk>a fast and lightweight file manager</mk>
   <nb>a fast and lightweight file manager</nb>
   <nl>een snelle en lichtgewicht bestandsmanager</nl>
   <pl>szybki i lekki menedżer plików</pl>
   <pt_BR>Gestor de ficheiros ligeiro e rápido</pt_BR>
   <pt>Gestor de ficheiros ligeiro e rápido</pt>
   <ro>a fast and lightweight file manager</ro>
   <ru>Быстрый и легковесный файловый менеджер</ru>
   <sk>a fast and lightweight file manager</sk>
   <sl>a fast and lightweight file manager</sl>
   <sq>a fast and lightweight file manager</sq>
   <sr>a fast and lightweight file manager</sr>
   <sv>en snabb lättvikts filhanterare</sv>
   <tr>a fast and lightweight file manager</tr>
   <uk>швидкий та легкий файловий менеджер</uk>
   <zh_CN>a fast and lightweight file manager</zh_CN>
   <zh_TW>a fast and lightweight file manager</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/000/678/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
pcmanfm
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
pcmanfm
</uninstall_package_names>
</app>
